// import CSV file created by Alex and augmented with the unemployment rate by Luca -- to do, add BBB corporate yield and spread
import delimited G:\ofs\research2\Guerrieri\matlab\quantile_regressions\c2gdp_data.csv, clear

// save as STATA dataset 
save "G:\ofs\research2\Guerrieri\matlab\quantile_regressions\c2gdp_data.dta", replace

// reload 
use "G:\ofs\research2\Guerrieri\matlab\quantile_regressions\c2gdp_data.dta", clear

// turn excel dates to stata dates 
gen date2 = date(date, "MDY",2050)
format date2 %td

drop date
ren date2 date

gen    year = year(date)
gen    qtr = quarter(date)
gen    qdate = yq(year,qtr)
format qdate %tq

// arrange data as a time series in qdate
xtset qdate

// construct inflation series from PCE deflator
gen infl=100*(log(pce_deflator[_n])-log(pce_deflator[_n-4]))
gen infl_l4q = infl[_n-4]

// create the 4-quarter change in the unemployment rate
gen dunemployment_4q = unemployment[_n]-unemployment[_n-4]
 
 // unemployment rate lagged 4 quarters
gen unemployment_l4q = unemployment[_n-4]

// 16-quarter change in the credit to GDP ratio, then lagged 4 quarters
gen  dc2gdp_16q_l4q = 100*(log(c2gdp[_n-4])-log(c2gdp[_n-20]))

set seed 121

// First regression -- aggregate credit
// d(4q)unemployment_t regressed over unemployment_{t-4}   d(16q)c2gdp_{t-4}
qreg dunemployment_4q  unemployment_l4q infl_l4q dc2gdp_16q_l4q, q(0.25)



grqreg, ci  list reps(1000) seed(121) name(first, replace) 


gen  dnfbus_ratio_16q_l4q = 100*(log(nfbus_ratio_lv[_n-4])-log(nfbus_ratio_lv[_n-20]))
gen  dhh_ratio_16q_l4q= 100*(log(hh_ratio_lv[_n-4])-log(hh_ratio_lv[_n-20]))

// Second regression -- household and business credit
qreg dunemployment_4q  unemployment_l4q infl_l4q dnfbus_ratio_16q_l4q  dhh_ratio_16q_l4q, q(0.25)
grqreg, ci  list reps(1000) seed(121) name(second, replace)

// Third regression -- add corporate spreads, but lose observations since series starts later
gen bbb_spread_l4q = bbb_spread[_n-4]
qreg dunemployment_4q  unemployment_l4q infl_l4q bbb_spread_l4q dnfbus_ratio_16q_l4q  dhh_ratio_16q_l4q, q(0.25)
grqreg, ci  list reps(1000) seed(121) name(third, replace)

// Fourth regression -- use NFCI
gen nfci_l4q = nfci[_n-4]
qreg dunemployment_4q  unemployment_l4q infl_l4q nfci_l4q, q(0.25)
grqreg, ci  list reps(1000) seed(121) name(fourth,replace)


// Fifth regression -- use NFCI and BBB
qreg dunemployment_4q  unemployment_l4q infl_l4q nfci_l4q bbb_spread_l4q, q(0.25)
grqreg, ci  list reps(1000) seed(121) name(fifth,replace)


// Sixth regression -- use NFCI and BBB and business credit
qreg dunemployment_4q  unemployment_l4q infl_l4q nfci_l4q bbb_spread_l4q dnfbus_ratio_16q_l4q, q(0.25)
grqreg, ci  list reps(1000) seed(121) name(sixth, replace)


